package com.brilliance.pack;

import java.io.File;
import java.util.LinkedList;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import com.brilliance.dzxt.framework.Result;
import com.brilliance.dzxt.packet.model.com.BrnchId;
import com.brilliance.dzxt.packet.model.com.GrpHdr;
import com.brilliance.dzxt.packet.model.com.InstdAgt;
import com.brilliance.dzxt.packet.model.com.InstgAgt;
import com.brilliance.dzxt.packet.model.com.MsgPgntn;
import com.brilliance.dzxt.packet.model.elcs_720_001_01.Elcs_720_001_01;
import com.brilliance.dzxt.packet.model.elcs_720_001_01.Ntry;
import com.brilliance.dzxt.packet.model.elcs_720_001_01.Rpt;
import com.brilliance.dzxt.utils.MsgUtil;

public class Elcs_720_001_01Test {
	Elcs_720_001_01 elcs_720_001_01;
	GrpHdr grpHdr;
	MsgPgntn msgPgntn;
	Rpt rpt;

	@Before
	public void setUp() {
		BrnchId brnchId = new BrnchId("brnchId0001");
		InstgAgt instgAgt = new InstgAgt("MmbId0001", brnchId);
		brnchId = new BrnchId("brnchId0002");
		InstdAgt instdAgt = new InstdAgt("MmbId0002", brnchId);
		grpHdr = new GrpHdr("201908211112000001", "2010-09-01 10:09:05",
				instgAgt, instdAgt, "ELCS", "elcs_720_001_01 test");
		msgPgntn=new MsgPgntn("1", "TRUE");
		List<Ntry> ntrylst= new LinkedList<Ntry>();
		Ntry ntry=new Ntry("msgid001", "SNDR", "FQJG01", "elcs_720_001_01", "PDNG");
		ntrylst.add(ntry);
		ntry=new Ntry("msgid002", "SNDR", "FQJG02", "elcs_720_001_01", "PDNG");
		ntrylst.add(ntry);
		rpt=new Rpt("2019-09-01", "BANK00001", ntrylst);
		elcs_720_001_01=new Elcs_720_001_01("102100099998", "103100022226",
				"20190901", "094508", "elcs.720.001.01",
				"A1234B1234C1234D1234", "00000000000000000000", "U", grpHdr, msgPgntn, rpt);
	}

	/**
	 * elcs.720.001.01类型报文打包和解包测试
	 */
	@Test
	public void testPackAndUnpack() {
		try {
			Result reqResult = MsgUtil.packMessage(elcs_720_001_01);
			System.out.println("Elcs_720_001_01报文头==" + reqResult.getHead());
			System.out.println("Elcs_720_001_01签名部分==" + reqResult.getSignature());
			System.out.println("Elcs_720_001_01报文体部分==" + reqResult.getBody());
			System.out.println("Elcs_720_001_01完整报文==" + reqResult.getMessage());
			System.out.println("Elcs_720_001_01模型json串==" + reqResult.getElcsModelForJson());
			
			//模拟人行请求报文文件
			reqResult.saveMessageForXml("D:/elcs.720.001.01.xml");
			//这里模拟收到人行的报文（头部+签名域+报文体）进行解析
			//支持三种API 1.字符串 2.字节数组 3.报文文件
			//下面以Elcs_720_001_01完整报文字符串，调用报文文件API解包
			Result resResult=MsgUtil.unPackMessage(new File("D:/elcs.720.001.01.xml"));
			System.out.println("本地保存完整报文:"+resResult.getMessageType());
			
			//下面可以根据指定的路径，将报文保存到本地
//			resResult.saveMessageForXml("D:/elcs.720.001.01.xml");
			//扁平化结构，是把报文模型所有字段层级以.进行拼接，最后以map保存
			System.out.println("本地保存完整报文模型扁平化结构:"+resResult.getElcsFlatHierarchy());
			//下面可以根据指定的路径，将报文扁平化结构保存到本地
//			resResult.saveElcsFlatHierarchy("D:/elcs.720.001.01.json");
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
}
